@@ -12,7 +12,6 @@ from typing import Optional, Union
 import pytesseract
 from PIL import Image
 from PIL.ExifTags import TAGS
-from rich.text import Text
 
 from clown_sort.config import Config
 from clown_sort.util.logging import log
@@ -30,13 +29,12 @@ EXIF_CODES = {
 
 
 class ImageFile(SortableFile):
-    def move_file_to_sorted_dir(self, destination_subdir: Optional[Union[Path, str]] = None) -> Path:
+    def copy_file_to_sorted_dir(self, destination_path: Path) -> Path:
         """
         Copies to a new file and injects the ImageDescription exif tag.
         If :destination_subdir is given new file will be in :destination_subdir off
         of the configured :destination_dir. Returns new file path.
         """
-        destination_path = self.sort_destination_path(destination_subdir)
         exif_data = self.raw_exif_dict()
         exif_data.update([(EXIF_CODES[IMAGE_DESCRIPTION], self.extracted_text())])
         self._log_copy_file(destination_path)
@@ -83,6 +81,10 @@ class ImageFile(SortableFile):
 
         self._extracted_text = pytesseract.image_to_string(self.pillow_image_obj())
         self.text_extraction_attempted = True
+
+        if self._extracted_text is not None:
+            self._extracted_text = self._extracted_text.strip()
+
         return self._extracted_text
 
     def exif_dict(self) -> dict:
@@ -95,6 +97,7 @@ class ImageFile(SortableFile):
         return self.pillow_image_obj().getexif()
 
     def pillow_image_obj(self) -> Image.Image:
+        """Return the file as Pillow Image object."""
         return Image.open(self.file_path)
 
     def __repr__(self) -> str:
